@@ -1,7 +1,7 @@
 /*
  *  hook.c
  *
- *  Copyright (c) 2015-2018 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2015-2019 Pacman Development Team <pacman-dev@archlinux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
 #include <limits.h>
@@ -38,7 +37,7 @@ enum _alpm_hook_op_t {
 
 enum _alpm_trigger_type_t {
 	ALPM_HOOK_TYPE_PACKAGE = 1,
-	ALPM_HOOK_TYPE_FILE,
+	ALPM_HOOK_TYPE_PATH,
 };
 
 struct _alpm_trigger_t {
@@ -71,23 +70,12 @@ static void _alpm_trigger_free(struct _alpm_trigger_t *trigger)
 	}
 }
 
-static void _alpm_wordsplit_free(char **ws)
-{
-	if(ws) {
-		char **c;
-		for(c = ws; *c; c++) {
-			free(*c);
-		}
-		free(ws);
-	}
-}
-
 static void _alpm_hook_free(struct _alpm_hook_t *hook)
 {
 	if(hook) {
 		free(hook->name);
 		free(hook->desc);
-		_alpm_wordsplit_free(hook->cmd);
+		wordsplit_free(hook->cmd);
 		alpm_list_free_inner(hook->triggers, (alpm_list_fn_free) _alpm_trigger_free);
 		alpm_list_free(hook->triggers);
 		alpm_list_free(hook->matches);
@@ -158,107 +146,6 @@ static int _alpm_hook_validate(alpm_handle_t *handle,
 	return ret;
 }
 
-static char **_alpm_wordsplit(char *str)
-{
-	char *c = str, *end;
-	char **out = NULL, **outsave;
-	size_t count = 0;
-
-	if(str == NULL) {
-		errno = EINVAL;
-		return NULL;
-	}
-
-	for(c = str; isspace(*c); c++);
-	while(*c) {
-		size_t wordlen = 0;
-
-		/* extend our array */
-		outsave = out;
-		if((out = realloc(out, (count + 1) * sizeof(char*))) == NULL) {
-			out = outsave;
-			goto error;
-		}
-
-		/* calculate word length and check for unbalanced quotes */
-		for(end = c; *end && !isspace(*end); end++) {
-			if(*end == '\'' || *end == '"') {
-				char quote = *end;
-				while(*(++end) && *end != quote) {
-					if(*end == '\\' && *(end + 1) == quote) {
-						end++;
-					}
-					wordlen++;
-				}
-				if(*end != quote) {
-					errno = EINVAL;
-					goto error;
-				}
-			} else {
-				if(*end == '\\' && (end[1] == '\'' || end[1] == '"')) {
-					end++; /* skip the '\\' */
-				}
-				wordlen++;
-			}
-		}
-
-		if(wordlen == (size_t) (end - c)) {
-			/* no internal quotes or escapes, copy it the easy way */
-			if((out[count++] = strndup(c, wordlen)) == NULL) {
-				goto error;
-			}
-		} else {
-			/* manually copy to remove quotes and escapes */
-			char *dest = out[count++] = malloc(wordlen + 1);
-			if(dest == NULL) { goto error; }
-			while(c < end) {
-				if(*c == '\'' || *c == '"') {
-					char quote = *c;
-					/* we know there must be a matching end quote,
-					 * no need to check for '\0' */
-					for(c++; *c != quote; c++) {
-						if(*c == '\\' && *(c + 1) == quote) {
-							c++;
-						}
-						*(dest++) = *c;
-					}
-					c++;
-				} else {
-					if(*c == '\\' && (c[1] == '\'' || c[1] == '"')) {
-						c++; /* skip the '\\' */
-					}
-					*(dest++) = *(c++);
-				}
-			}
-			*dest = '\0';
-		}
-
-		if(*end == '\0') {
-			break;
-		} else {
-			for(c = end + 1; isspace(*c); c++);
-		}
-	}
-
-	outsave = out;
-	if((out = realloc(out, (count + 1) * sizeof(char*))) == NULL) {
-		out = outsave;
-		goto error;
-	}
-
-	out[count++] = NULL;
-
-	return out;
-
-error:
-	/* can't use wordsplit_free here because NULL has not been appended */
-	while(count) {
-		free(out[--count]);
-	}
-	free(out);
-	return NULL;
-}
-
 static int _alpm_hook_parse_cb(const char *file, int line,
 		const char *section, char *key, char *value, void *data)
 {
@@ -303,7 +190,11 @@ static int _alpm_hook_parse_cb(const char *file, int line,
 			if(strcmp(value, "Package") == 0) {
 				t->type = ALPM_HOOK_TYPE_PACKAGE;
 			} else if(strcmp(value, "File") == 0) {
-				t->type = ALPM_HOOK_TYPE_FILE;
+				_alpm_log(handle, ALPM_LOG_DEBUG,
+						"File targets are deprecated, use Path instead\n");
+				t->type = ALPM_HOOK_TYPE_PATH;
+			} else if(strcmp(value, "Path") == 0) {
+				t->type = ALPM_HOOK_TYPE_PATH;
 			} else {
 				error(_("hook %s line %d: invalid value %s\n"), file, line, value);
 			}
@@ -343,9 +234,9 @@ static int _alpm_hook_parse_cb(const char *file, int line,
 		} else if(strcmp(key, "Exec") == 0) {
 			if(hook->cmd != NULL) {
 				warning(_("hook %s line %d: overwriting previous definition of %s\n"), file, line, "Exec");
-				_alpm_wordsplit_free(hook->cmd);
+				wordsplit_free(hook->cmd);
 			}
-			if((hook->cmd = _alpm_wordsplit(value)) == NULL) {
+			if((hook->cmd = wordsplit(value)) == NULL) {
 				if(errno == EINVAL) {
 					error(_("hook %s line %d: invalid value %s\n"), file, line, value);
 				} else {
@@ -551,7 +442,16 @@ static int _alpm_hook_triggered(alpm_handle_t *handle, struct _alpm_hook_t *hook
 
 static int _alpm_hook_cmp(struct _alpm_hook_t *h1, struct _alpm_hook_t *h2)
 {
-	return strcmp(h1->name, h2->name);
+	size_t suflen = strlen(ALPM_HOOK_SUFFIX), l1, l2;
+	int ret;
+	l1 = strlen(h1->name) - suflen;
+	l2 = strlen(h2->name) - suflen;
+	/* exclude the suffixes from comparison */
+	ret = strncmp(h1->name, h2->name, l1 <= l2 ? l1 : l2);
+	if(ret == 0 && l1 != l2) {
+		return l1 < l2 ? -1 : 1;
+	}
+	return ret;
 }
 
 static alpm_list_t *find_hook(alpm_list_t *haystack, const void *needle)
@@ -634,8 +534,7 @@ int _alpm_hook_run(alpm_handle_t *handle, alpm_hook_when_t when)
 	alpm_event_hook_t event = { .when = when };
 	alpm_event_hook_run_t hook_event;
 	alpm_list_t *i, *hooks = NULL, *hooks_triggered = NULL;
-	const char *suffix = ".hook";
-	size_t suflen = strlen(suffix), triggered = 0;
+	size_t suflen = strlen(ALPM_HOOK_SUFFIX), triggered = 0;
 	int ret = 0;
 
 	for(i = alpm_list_last(handle->hookdirs); i; i = alpm_list_previous(i)) {
@@ -681,7 +580,7 @@ int _alpm_hook_run(alpm_handle_t *handle, alpm_hook_when_t when)
 			memcpy(path + dirlen, entry->d_name, name_len + 1);
 
 			if(name_len < suflen
-					|| strcmp(entry->d_name + name_len - suflen, suffix) != 0) {
+					|| strcmp(entry->d_name + name_len - suflen, ALPM_HOOK_SUFFIX) != 0) {
 				_alpm_log(handle, ALPM_LOG_DEBUG, "skipping non-hook file %s\n", path);
 				continue;
 			}
